@@ -7,7 +7,7 @@ from typing import Optional
 import zmq
 
 from openmodule.alert import AlertHandler
-from openmodule.config import validate_config_module, database_folder
+from openmodule.config import validate_config_module, settings
 from openmodule.database.database import Database
 from openmodule.dispatcher import SubscribingMessageDispatcher
 from openmodule.health import HealthHandlerType, Healthz, HealthPingMessage
@@ -45,9 +45,9 @@ class OpenModuleCore(threading.Thread):
 
     def init_database(self):
         if self.config.TESTING:
-            self.database = Database(database_folder(), self.config.NAME, alembic_path="../src/database")
+            self.database = Database(settings.DATABASE_FOLDER, self.config.NAME, alembic_path="../src/database")
         else:
-            self.database = Database(database_folder(), self.config.NAME)
+            self.database = Database(settings.DATABASE_FOLDER, self.config.NAME)
 
     def _run(self):
         try:
