@@ -11,6 +11,8 @@ from sqlalchemy.engine import Engine
 from sqlalchemy.orm import sessionmaker, Session
 from sqlalchemy.pool import StaticPool
 
+from openmodule.checks import check_invalid_database_column_type
+
 
 @event.listens_for(Engine, "connect")
 def set_sqlite_pragma(dbapi_connection, connection_record):
@@ -54,8 +56,9 @@ def register_bases(bases, show_deprecation_warning=True):
 
     for base in bases:
         for table in base.metadata.tables.values():
+            for x in table.columns:
+                check_invalid_database_column_type(x.type)
             table.tometadata(target_metadata)
-
     context.config.attributes["target_metadata"] = target_metadata
 
 
@@ -80,6 +83,7 @@ def get_database(db_folder: str, name: str, alembic_path=None):
     engine = create_engine(path, poolclass=StaticPool, connect_args={'check_same_thread': False})
     migrate_database(engine, alembic_path)
     active_databases[tmp] = engine
+
     return engine
 
 
@@ -127,6 +131,10 @@ class Database:
         self.active_session = self._session(expire_on_commit=expire_on_commit)
         return self.active_session
 
+    def flush(self, objects=None):
+        assert self._session
+        self.active_session.flush(objects)
+
     def __exit__(self, exc_type, exc_val, exc_tb):
         try:
             if exc_type is None:
