@@ -8,6 +8,7 @@ from pydantic import Field, BaseModel, validator
 from pydantic.main import ROOT_KEY
 
 from openmodule import config
+from openmodule.config import settings
 
 
 def _donotuse(v, *, default):
@@ -77,6 +78,12 @@ class ZMQMessage(OpenModuleModel):
     name: str
     type: str
 
+    def __init__(self, **kwargs):
+        name = kwargs.pop("name", None)
+        if name is None:
+            name = settings.NAME
+        super().__init__(name=name, **kwargs)
+
     _tz_timestamp = timezone_validator("timestamp")
 
     def publish_on_topic(self, pub_socket: zmq.Socket, topic: bytes):
