@@ -1,9 +1,9 @@
 from unittest import TestCase
 
 from openmodule.alert import AlertHandleType
+from openmodule.config import settings
 from openmodule.core import core, init_openmodule, shutdown_openmodule
 from openmodule_test.alert import AlertTestMixin
-from openmodule_test.core import OpenModuleCoreTestMixin
 from openmodule_test.health import HealthTestMixin
 
 
@@ -38,7 +38,7 @@ class OpenModuleCoreTest(AlertTestMixin, HealthTestMixin, TestCase):
         self.wait_for_health()
 
         try:
-            core().alerts.send("some-source", "some_type", AlertHandleType.state_change)
+            core().alerts.send("some_type", AlertHandleType.state_change)
             self.assertAlert(alert_type="some_type")
         finally:
             shutdown_openmodule()
