@@ -1,10 +1,14 @@
+import os
+import time
 from datetime import datetime, timedelta
 from typing import Optional
 from unittest import TestCase
 
+import freezegun
 import orjson
 from pydantic import ValidationError
 
+from openmodule.models.backend import Access
 from openmodule.models.base import OpenModuleModel, ZMQMessage, Gateway
 
 
@@ -59,19 +63,23 @@ class ModelTestCase(TestCase):
 class ZMQMessageTestCase(TestCase):
     def test_timestamp_to_datetime(self):
         instance = ZMQMessage(timestamp=1607586354631, name="test", type="test")
-        self.assertEqual(instance.timestamp.isoformat(), "2020-12-10T07:45:54.631000+00:00")
+        self.assertEqual(instance.timestamp.isoformat(), "2020-12-10T07:45:54.631000")
 
     def test_timestamp_is_now_if_unset(self):
         instance = ZMQMessage(name="test", type="test")
         self.assertAlmostEqual(instance.timestamp, datetime.now(), delta=timedelta(seconds=1))
 
     def test_datetime_is_serialized_to_unix_timestamp(self):
-        instance = ZMQMessage(name="test", type="test")
-        json = instance.json_bytes()
+        with freezegun.freeze_time("2020-01-01 00:00"):
+            instance = ZMQMessage(name="test", type="test")
+            json = instance.json_bytes()
+            loaded_json = orjson.loads(json)
+            self.assertIsInstance(loaded_json["timestamp"], float)
+            self.assertEqual(loaded_json["timestamp"], 1577836800)
 
-        loaded_json = orjson.loads(json)
-        self.assertIsInstance(loaded_json["timestamp"], float)
-        self.assertAlmostEqual(loaded_json["timestamp"], datetime.now().timestamp(), delta=1)
+        instance = ZMQMessage(name="test", type="test")
+        instance.timestamp = datetime(2020, 1, 1, 0, 0, 0, 0)
+        self.assertEqual(instance.dict()["timestamp"], 1577836800)
 
     def test_receive_optional_gateway(self):
         class OptionalGateway(ZMQMessage):
@@ -86,7 +94,7 @@ class ZMQMessageTestCase(TestCase):
         self.assertEqual(message.gateway.direction, "in")
         self.assertEqual(message.gateway.gate, "")
 
-        with self.assertRaises(ValidationError)  as e:
+        with self.assertRaises(ValidationError) as e:
             OptionalGateway(name="test", gateway={"direction": "incorrect"})
 
         errors = e.exception.errors()
