@@ -1,19 +1,21 @@
-import calendar
 from datetime import datetime
 from unittest import TestCase
 
 import freezegun
 from dateutil.parser import parse
-from dateutil.tz import UTC
 
+from openmodule.config import settings
 from openmodule.models.backend import Access, AccessCategory
-from openmodule.models.base import ZMQMessage
 
 
 class AccessModelTestCase(TestCase):
     def assertTzNaive(self, d):
         self.assertTrue(d.tzinfo is None)
 
+    def tearDown(self) -> None:
+        super().tearDown()
+        settings.reset()
+
     def is_valid_at(self, access, dt, timezone="Europe/Vienna"):
         dt = parse(dt)
         return access.is_valid_at(dt, timezone)
