@@ -232,11 +232,12 @@ class MatchingTest(unittest.TestCase):
     def test_matching_order_ed1(self):
         plates_ed1 = [gen_plate(["X-YZ"], ["F", "OTHER"]), gen_plate(["X-YZ"], ["OTHER"]), gen_plate(["XYZA"], ["D"]),
                       gen_plate(["XYZA"], ["CH"])]
-        results_ed1 = [[0, 0, 2, -1], [2, 2, 2, -1], [2, 1, -1, -1]]
+        results_ed1 = [[0, 0, 2, -1], [2, 2, 2, -1], [2, 1, -1, -1], [2, 0, -1, -1]]
         dbs_ed1 = [
             prepare_db([("X:YZ", "A", 10), ("X YZ", "TEST", 40), ("XYZ", "D", 0), ("X YZ", "F", 30)], []),
             prepare_db([("X YZ", "A", 20), ("X YZ", "TEST", 40), ("XYZ", "D", 0), ("X YZ", "F", 30)], []),
-            prepare_db([("X YZ", "A", 20), ("X YZ", "TEST", 40), ("X YZ", "F", 30)], [])
+            prepare_db([("X YZ", "A", 20), ("X YZ", "TEST", 40), ("X YZ", "F", 30)], []),
+            prepare_db([("X YZ", "A", 20), ("X YZ", "TEST", 40), ("X YZ", "F", 30)], ["A"])
         ]
 
         for i, db1 in enumerate(dbs_ed1):
